@@ -10,7 +10,7 @@ import requests
 
 # Project imports
 import disruptive as dt
-import disruptive.log as dtlog
+import disruptive.logging as dtlog
 import disruptive.errors as dterrors
 
 
@@ -109,7 +109,8 @@ class DTRequest():
                 headers=headers,
                 json=body,
                 data=data,
-                timeout=timeout
+                timeout=timeout,
+                stream=False,
             )
 
             # Isolate the data of interest in the response.
@@ -161,7 +162,7 @@ class DTRequest():
 
             dtlog.log("Got error {}. Will retry up to {} more times".format(
                 error,
-                dt.request_retries - nth_attempt,
+                self.request_retries - nth_attempt,
             ), override=self.log)
 
             # Sleep if necessary.
@@ -317,7 +318,7 @@ class DTRequest():
             headers['Authorization'] = dt.default_auth.get_token()
 
         # Set up a simple catch-all retry policy.
-        nth_attempt = 0
+        nth_attempt = 1
         while nth_attempt <= request_retries:
             # Check if error is set.
             if error is not None:
@@ -328,12 +329,15 @@ class DTRequest():
                 # Connection will timeout and reconnect if no single event
                 # is received in an interval of ping_interval + ping_jitter.
                 dtlog.log('Starting stream...')
-                stream = requests.get(
+                stream = requests.request(
+                    method='GET',
                     url=url,
                     stream=True,
                     timeout=PING_INTERVAL + PING_JITTER,
                     params=params,
                     headers=headers,
+                    json=None,
+                    data=None,
                 )
 
                 # Iterate through the events as they come in (one per line).
@@ -355,6 +359,9 @@ class DTRequest():
                     # Yield event to generator.
                     yield event
 
+                # If the stream finished, but without an error, break the loop.
+                break
+
             except KeyboardInterrupt:
                 break
 
