@@ -5,34 +5,35 @@ from typing import Optional
 
 # Project imports.
 import disruptive
+import disruptive.logging as dtlog
 import disruptive.requests as dtrequests
 import disruptive.outputs as dtoutputs
-import disruptive.dataconnector_configs.dataconnector_configs as dcon_configs
 from disruptive.outputs import Metric
 
 
 class DataConnector(dtoutputs.OutputBase):
     """
-    Represents a dataconnector.
+    Represents a Data Connector.
 
-    When a dataconnector response is received, the content
-    is unpacked and the related attributes are updated.
+    When a Data Connector response is received, the content
+    is unpacked and the related attributes are set.
 
     Attributes
     ----------
     dataconnector_id : str
-        Unique dataconnector ID.
+        Unique Data Connector ID.
     project_id : str
-        Unique ID of the project where the dataconnector recides.
+        Unique ID of the project where the Data Connector resides.
     display_name : str
         The provided display name.
     dataconnector_type : str
-        Dataconnector type. Currently only HTTP_PUSH is available.
+        Dataconnector type. Currently, only HTTP_PUSH is available.
     status : str
         Whether the dataconnector is
         "ACTIVE", "USER_DISABLED", or "SYSTEM_DISABLED".
-    config : HttpPush, None
+    config : HttpPushConfig, None
         An object representing the type-specific configuration.
+        If an unknown Data Connector type is receiver, this is None.
     event_Types : list[str]
         List of event types that should be forwarded.
         If empty, all event types are forwarded.
@@ -43,7 +44,7 @@ class DataConnector(dtoutputs.OutputBase):
     """
 
     # Constants for the various dataconnector configuration types.
-    HTTP_PUSH = 'HttpPush'
+    HTTP_PUSH = 'HTTP_PUSH'
     DATACONNECTOR_TYPES = [HTTP_PUSH]
 
     def __init__(self, dataconnector: dict) -> None:
@@ -69,7 +70,7 @@ class DataConnector(dtoutputs.OutputBase):
         self.event_types = dataconnector['events']
         self.labels = dataconnector['labels']
         self.dataconnector_type = dataconnector['type']
-        self.config = dcon_configs._from_dict(dataconnector)
+        self.config = self._from_dict(dataconnector)
 
     @classmethod
     def get_dataconnector(cls,
@@ -78,7 +79,7 @@ class DataConnector(dtoutputs.OutputBase):
                           **kwargs,
                           ) -> DataConnector:
         """
-        Gets a dataconnector specified by its ID.
+        Gets the current state of a single Data Connector.
 
         Parameters
         ----------
@@ -97,7 +98,14 @@ class DataConnector(dtoutputs.OutputBase):
         Returns
         -------
         dataconnector : DataConnector
-            Object representing the specified dataconnector.
+            Object representing the target Data Connector.
+
+        Examples
+        --------
+        >>> dcon = disruptive.DataConnector.get_dataconnector(
+        ...     dataconnector_id='z19m68nlq0bgk84smxng',
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ... )
 
         """
 
@@ -117,7 +125,7 @@ class DataConnector(dtoutputs.OutputBase):
                             **kwargs,
                             ) -> list[DataConnector]:
         """
-        List all available dataconnectors in the specified project.
+        Gets a list of the current state of all dataconnectors in a project.
 
         Parameters
         ----------
@@ -136,6 +144,12 @@ class DataConnector(dtoutputs.OutputBase):
         dataconnectors : list[DataConnector]
             List of objects each representing a dataconnector.
 
+        Examples
+        --------
+        >>> dcons = disruptive.DataConnector.list_dataconnectors(
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ... )
+
         """
 
         # Return list of DataConnector objects of paginated GET response.
@@ -149,7 +163,7 @@ class DataConnector(dtoutputs.OutputBase):
     @classmethod
     def create_dataconnector(cls,
                              project_id: str,
-                             config: disruptive.dataconnector_configs.HttpPush,
+                             config: disruptive.DataConnector.HttpPushConfig,
                              display_name: str = '',
                              status: str = 'ACTIVE',
                              events: list[str] = [],
@@ -157,7 +171,7 @@ class DataConnector(dtoutputs.OutputBase):
                              **kwargs,
                              ) -> DataConnector:
         """
-        Create a new dataconnector in the specified project.
+        Creates a new dataconnector in the specified project.
 
         Parameters
         ----------
@@ -186,6 +200,17 @@ class DataConnector(dtoutputs.OutputBase):
         dataconnector : DataConnector
             Object representing the newly created dataconnector.
 
+        Examples
+        --------
+        >>> dcon = disruptive.DataConnector.create_dataconnector(
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ...     config=disruptive.dataconnector_configs.HttpPush(
+        ...         url='https://my-endpoint-url.com',
+        ...         signature_secret='very-good-secret',
+        ...     ),
+        ...     display_name='my-first-dcon',
+        ... )
+
         """
 
         # Construct request body dictionary.
@@ -216,7 +241,7 @@ class DataConnector(dtoutputs.OutputBase):
         cls,
         dataconnector_id: str,
         project_id: str,
-        config: Optional[disruptive.dataconnector_configs.HttpPush] = None,
+        config: Optional[disruptive.DataConnector.HttpPushConfig] = None,
         display_name: Optional[str] = None,
         status: Optional[str] = None,
         events: Optional[list[str]] = None,
@@ -225,6 +250,7 @@ class DataConnector(dtoutputs.OutputBase):
     ) -> DataConnector:
         """
         Updates the attributes of a dataconnector.
+        All parameters that are provided will be updated.
 
         Parameters
         ----------
@@ -250,6 +276,20 @@ class DataConnector(dtoutputs.OutputBase):
         request_retries: int, optional
             Maximum number of times to retry a request before giving up.
 
+        Returns
+        -------
+        dataconnector : DataConnector
+            Object representing the updated dataconnector.
+
+        Examples
+        --------
+        >>> dcon = disruptive.DataConnector.update_dataconnector(
+        ...     dataconnector_id='z19m68nlq0bgk84smxng',
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ...     display_name='new-name',
+        ...     events=['temperature', 'touch'],
+        ... )
+
         """
 
         # Construct request body dictionary.
@@ -302,6 +342,13 @@ class DataConnector(dtoutputs.OutputBase):
         request_retries: int, optional
             Maximum number of times to retry a request before giving up.
 
+        Examples
+        --------
+        >>> disruptive.DataConnector.delete_dataconnector(
+        ...     dataconnector_id='z19m68nlq0bgk84smxng',
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ... )
+
         """
 
         # Construct URL.
@@ -342,6 +389,13 @@ class DataConnector(dtoutputs.OutputBase):
         metric : Metric
             Object representing the fetched metrics.
 
+        Examples
+        --------
+        >>> metrics = disruptive.DataConnector.get_metrics(
+        ...     dataconnector_id='z19m68nlq0bgk84smxng',
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ... )
+
         """
 
         # Construct URL.
@@ -382,6 +436,13 @@ class DataConnector(dtoutputs.OutputBase):
         request_retries: int, optional
             Maximum number of times to retry a request before giving up.
 
+        Examples
+        --------
+        >>> disruptive.DataConnector.sync_dataconnector(
+        ...     dataconnector_id='z19m68nlq0bgk84smxng',
+        ...     project_id='y14u8p094l37cdv1o0ug',
+        ... )
+
         """
 
         # Construct URL.
@@ -394,3 +455,77 @@ class DataConnector(dtoutputs.OutputBase):
             url=url,
             **kwargs,
         )
+
+    @classmethod
+    def _from_dict(cls, dataconnector: dict):
+        # Isolate the dataconnector type.
+        dataconnector_type = dataconnector['type']
+
+        # Select the appropriate config depending on type.
+        if dataconnector_type == 'HTTP_PUSH':
+            # Isolate config field.
+            config = dataconnector['httpConfig']
+
+            # Create and return an HttpPush object.
+            return cls.HttpPushConfig(
+                url=config['url'],
+                signature_secret=config['signatureSecret'],
+                headers=config['headers'],
+            )
+        else:
+            # If this else statement runs, no config is available for type.
+            dtlog.log('No config available for {} dataconnectors.'.format(
+                dataconnector_type
+            ))
+            return None
+
+    class HttpPushConfig():
+        """
+        Type-specific configurations for the HTTP_PUSH dataconnector.
+
+        Attributes
+        ----------
+        url : str
+            Endpoint URL towards which events are forwarded. Must be HTTPS.
+        signature_secret : str
+            Secret with which each forwarded event is signed.
+        headers : dict[str, str]
+            Dictionary of headers to include with each forwarded event.
+
+        """
+
+        dataconnector_type = 'HTTP_PUSH'
+
+        def __init__(self,
+                     url: Optional[str] = None,
+                     signature_secret: Optional[str] = None,
+                     headers: Optional[dict] = None,
+                     ) -> None:
+            """
+            Constructs the HttpPushConfig object.
+
+            Parameters
+            ----------
+            url : str, optional
+                Endpoint URL towards which events are forwarded. Must be HTTPS.
+            signature_secret : str, optional
+                Secret with which each forwarded event is signed.
+            headers : dict[str, str], optional
+                Dictionary of headers to include with each forwarded event.
+
+            """
+
+            # Set parameter attributes.
+            self.url = url
+            self.signature_secret = signature_secret
+            self.headers = headers
+
+        def _to_dict(self):
+            config: dict = dict()
+            if self.url is not None:
+                config['url'] = self.url
+            if self.signature_secret is not None:
+                config['signatureSecret'] = self.signature_secret
+            if self.headers is not None:
+                config['headers'] = self.headers
+            return 'httpConfig', config
